"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class AdRecord {
    constructor(obj) {
        const { id, name, description, price, url, lat, lon } = obj;
        if (!name || name.length > 100) {
            throw new errors_1.ValidateError('Nazwa ogłoszenia nie może być pusta, ani przekraczać 100 znaków.');
        }
        if (description.length > 1000) {
            throw new errors_1.ValidateError('Treść ogłoszenia nie może przekraczać 1000 znaków.');
        }
        if (price < 0 || price > 9999999) {
            throw new errors_1.ValidateError('Cena nie może być mniejsza niż 0 lub większa niż 9 999 999');
        }
        if (!url || url.length > 100) {
            throw new errors_1.ValidateError('Link ogłoszenia nie może być pusty, ani przekraczać 100 znaków.');
        }
        if (typeof lat !== 'number' || typeof lon !== 'number') {
            throw new errors_1.ValidateError('Nie można zlokalizować ogłoszenia.');
        }
        this.id = id;
        this.name = name;
        this.description = description;
        this.price = price;
        this.url = url;
        this.lat = lat;
        this.lon = lon;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('select * from ads where id = :id', {
                id,
            });
            return results.length === 0 ? null : new AdRecord(results[0]);
        });
    }
    static findAll(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('select * from ads where name like :search', {
                search: `%${name}%`,
            });
            return results.map(result => {
                const { id, lat, lon } = result;
                return {
                    id, lat, lon
                };
            });
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot inserted something that is already inserted!');
            }
            yield db_1.pool.execute('insert into ads (id, name, description, price, url, lat, lon) ' +
                'values (:id, :name, :description, :price, :url, :lat, :lon)', this);
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map