import express, {json, Router} from 'express';
import cors from 'cors';
import rateLimit from 'express-rate-limit'
import 'express-async-errors';
import {handleError} from "./utils/errors";
import {adRouter} from "./routers/ad.router";
import {config} from "./config/config";

const router = Router();
const app = express();

router.use('/ad', adRouter);

app
    .use(cors({
        origin: config.corsOrigin,
    }))
    .use(json())
    .use(rateLimit({
        windowMs: 5 * 60 * 1000, // 5 minutes
        max: 100, // Limit each IP to 100 requests per `window` (here, per 15 minutes)
    }))
    .use('/api', router)
    .use(handleError)
    .listen(3001, '0.0.0.0', () => {
        console.log('Listening on http://localhost:3001')
    })
